@@ -19,6 +19,8 @@
 #include <os2.h>
 #endif
 
+#include <pthread.h>
+
 PR_BEGIN_EXTERN_C
 
 /*---------------------------------------------------------------------------
@@ -59,7 +61,7 @@ NSPR_API(void) PR_DetachThread(void);
 ** Get the id of the named thread. Each thread is assigned a unique id
 ** when it is created or attached.
 */
-NSPR_API(PRUint32) PR_GetThreadID(PRThread *thread);
+NSPR_API(pthread_t) PR_GetThreadID(PRThread *thread);
 
 /*
 ** Set the procedure that is called when a thread is dumped. The procedure
@@ -301,9 +303,9 @@ NSPR_API(void) PR_OS2_UnsetFloatExcpHandler(EXCEPTIONREGISTRATIONRECORD* e);
 ---------------------------------------------------------------------------*/
 
 #ifdef XP_UNIX
-extern void PR_XLock(void);
-extern void PR_XUnlock(void);
-extern PRBool PR_XIsLocked(void);
+extern void _PR_XLock(void);
+extern void _PR_XUnlock(void);
+extern PRBool _PR_XIsLocked(void);
 #endif /* XP_UNIX */
 
 PR_END_EXTERN_C
